Default implementation of the AshEvents.AdvisoryLockKeyGenerator behaviour.
Handles the attribute-strategy for multitenancy, if the tenant value used is an
integer or uuid. For other scenarios, users must implemeent a custom implementation
and declare it in their event-log resource configuration.
Summary
Functions
Callback implementation for AshEvents.AdvisoryLockKeyGenerator.generate_key!/2.
Functions
Callback implementation for AshEvents.AdvisoryLockKeyGenerator.generate_key!/2.