AshEvents.EventLog.Verifiers.VerifyReplayOverrides (ash_events v0.7.0)

Copy Markdown View Source

Verifies that replay_overrides configuration is valid.

Checks that:

  • route_to.resource references an existing Ash resource
  • route_to.action references an existing action on the route_to.resource

Note: event_resource and event_action are not validated as existing since they may have been removed after events were created for them.