Specialized wrapper for validations that preserves custom messages during event tracking.
This wrapper ensures that custom validation messages are preserved when using AshEvents, while still allowing for replay-specific behavior during event replay.
Summary
Functions
Callback implementation for Ash.Resource.Change.change/3.
Functions
Callback implementation for Ash.Resource.Change.change/3.