A validation that always fails. Used as a where condition to create
non-executing changes that exist only for introspection by other libraries
(e.g., AshPhoenix nested form detection).
A validation that always fails. Used as a where condition to create
non-executing changes that exist only for introspection by other libraries
(e.g., AshPhoenix nested form detection).