A change that runs LAST during replay to apply changed_attributes.
This ensures that any attributes set by business logic changes (like set_attribute) are overwritten with the exact values from when the original event was created.
The primary key is handled separately by ApplyReplayPrimaryKey which runs first.
Summary
Functions
Callback implementation for Ash.Resource.Change.atomic/3.
Callback implementation for Ash.Resource.Change.change/3.
Functions
Callback implementation for Ash.Resource.Change.atomic/3.
Callback implementation for Ash.Resource.Change.change/3.